@@ -20,8 +20,14 @@ fi
 
 export BAPY PEN name url; debug.sh BAPY PEN name url
 
-if error="$( ${SUDO} "${PYTHON38}" -m pip uninstall "${name}" -y 2>&1 \
-       && ${SUDO} "${PYTHON38}" -m pip install --upgrade "${url}" 2>&1 )"; then
+#if error="$( ${SUDO} "${PYTHON38}" -m pip uninstall "${name}" -y 2>&1 \
+#       && ${SUDO} "${PYTHON38}" -m pip install --upgrade "${url}" 2>&1 )"; then
+#  info.sh install "${name}"
+#else
+#  error.sh install "${name}" "${error}"; exit 1
+#fi
+
+if error="$( ${SUDO} "${PYTHON38}" -m pip install --upgrade "${url}" 2>&1 )"; then
   info.sh install "${name}"
 else
   error.sh install "${name}" "${error}"; exit 1
